@@ -14,7 +14,6 @@
 
 #include "kalarmcal_debug.h"
 
-#include <QBitArray>
 #include <QDate>
 #include <QLocale>
 
@@ -35,10 +34,9 @@ public:
 class Q_DECL_HIDDEN KARecurrence::Private
 {
 public:
-    Private()
-        : mFeb29Type(Feb29_None), mCachedType(-1) {}
+    Private() {}
     explicit Private(const Recurrence &r)
-        : mRecurrence(r), mFeb29Type(Feb29_None), mCachedType(-1) {}
+        : mRecurrence(r) {}
     void clear()
     {
         mRecurrence.clear();
@@ -55,8 +53,8 @@ public:
 
     static Feb29Type mDefaultFeb29;
     Recurrence_p     mRecurrence;
-    Feb29Type        mFeb29Type;    // yearly recurrence on Feb 29th (leap years) / Mar 1st (non-leap years)
-    mutable int      mCachedType;
+    Feb29Type        mFeb29Type = Feb29_None;    // yearly recurrence on Feb 29th (leap years) / Mar 1st (non-leap years)
+    mutable int      mCachedType = -1;
 };
 
 QTimeZone KARecurrence::Private::toTimeZone(const KADateTime::Spec &spec)
@@ -515,7 +513,7 @@ void KARecurrence::Private::writeRecurrence(const KARecurrence *q, Recurrence &r
 
         // It recurs on the 29th February.
         // Create an additional 60th day of the year, or last day of February, rule.
-        RecurrenceRule *rrule2 = new RecurrenceRule();
+        auto *rrule2 = new RecurrenceRule();
         rrule2->setRecurrenceType(RecurrenceRule::rYearly);
         rrule2->setFrequency(freq);
         rrule2->setStartDt(mRecurrence.startDateTime());
@@ -627,7 +625,7 @@ KADateTime KARecurrence::Private::endDateTime() const
      * 4 years. So shift the temporary recurrence date to the 28th to ensure
      * that it occurs every year, thus giving the correct occurrence count.
      */
-    RecurrenceRule *rrule = new RecurrenceRule();
+    auto *rrule = new RecurrenceRule();
     rrule->setRecurrenceType(RecurrenceRule::rYearly);
     KADateTime dt = KADateTime(mRecurrence.startDateTime());
     QDate da = dt.date();
